---
title: json_schema
type: processor
status: stable
categories: ["Mapping"]
---

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the contents of:
     lib/processor/json_schema.go
-->

import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';


Checks messages against a provided JSONSchema definition but does not change the
payload under any circumstances. If a message does not match the schema it can
be caught using error handling methods outlined [here](/docs/configuration/error_handling).


<Tabs defaultValue="common" values={[
  { label: 'Common', value: 'common', },
  { label: 'Advanced', value: 'advanced', },
]}>

<TabItem value="common">

```yaml
# Common config fields, showing default values
label: ""
json_schema:
  schema: ""
  schema_path: ""
```

</TabItem>
<TabItem value="advanced">

```yaml
# All config fields, showing default values
label: ""
json_schema:
  schema: ""
  schema_path: ""
  parts: []
```

</TabItem>
</Tabs>

Please refer to the [JSON Schema website](https://json-schema.org/) for
information and tutorials regarding the syntax of the schema.

## Fields

### `schema`

A schema to apply. Use either this or the `schema_path` field.


Type: `string`  
Default: `""`  

### `schema_path`

The path of a schema document to apply. Use either this or the `schema` field.


Type: `string`  
Default: `""`  

### `parts`

An optional array of message indexes of a batch that the processor should apply to.
If left empty all messages are processed. This field is only applicable when
batching messages [at the input level](/docs/configuration/batching).

Indexes can be negative, and if so the part will be selected from the end
counting backwards starting from -1.


Type: `array`  
Default: `[]`  

## Examples

With the following JSONSchema document:

```json
{
	"$id": "https://example.com/person.schema.json",
	"$schema": "http://json-schema.org/draft-07/schema#",
	"title": "Person",
	"type": "object",
	"properties": {
	  "firstName": {
		"type": "string",
		"description": "The person's first name."
	  },
	  "lastName": {
		"type": "string",
		"description": "The person's last name."
	  },
	  "age": {
		"description": "Age in years which must be equal to or greater than zero.",
		"type": "integer",
		"minimum": 0
	  }
	}
}
```

And the following Benthos configuration:

```yaml
pipeline:
  processors:
  - json_schema:
      schema_path: "file://path_to_schema.json"
  - catch:
    - log:
        level: ERROR
        message: "Schema validation failed due to: ${!error()}"
    - bloblang: 'root = deleted()' # Drop messages that fail
```

If a payload being processed looked like:

```json
{"firstName":"John","lastName":"Doe","age":-21}
```

Then a log message would appear explaining the fault and the payload would be
dropped.

